local addonName = ...
local VERSION = GetAddOnMetadata(addonName, "Version")

local addon = CreateFrame("Frame", "ChaosBoltToTheFaceFrame", UIParent)

local partyKills = {}

local msgs = {
	kill_named_amount = {
		"%s got owned by my %s %s to the face!!!",
		"%s got sent to the graveyard by my %s %s to the face!!!",
	},
	kill_named_noamount = {
		"%s got owned by my %s to the face!!!",
		"%s got sent to the graveyard by my %s to the face!!!",
	},
	kill_nonamed_amount = {
		"Something got owned by my %s %s to the face!!!",
		"Something got sent to the graveyard by my %s %s to the face!!!",
	},
	kill_nonamed_noamount = {
		"Something got owned by my %s to the face!!!",
		"Something got sent to the graveyard by my %s to the face!!!",
	},
	nokill_named_amount = {
		"%s took my %s %s to the face!!!",
		"%s ate my %s %s to the face!!!",
	},
	nokill_named_noamount = {
		"%s took my %s to the face!!!",
		"%s ate my %s to the face!!!",
	},
	nokill_nonamed_amount = {
		"%s %s to the face!!!",
	},
	nokill_nonamed_noamount = {
		"%s to the face!!!",
	},
}

function addon:ShortNumber(number)
	if not number then return end

	if number >= 1000000000000 then
		return ("%.0fT"):format(number/1000000000000)
	elseif number >= 1000000000 then
		return ("%.0fB"):format(number/1000000000)
	elseif number >= 1000000 then
		return ("%.0fM"):format(number/1000000)
	elseif number >= 99999 then
		return ("%.0fK"):format(number/1000)
	else
		return addon:AddComma(number)
	end
end

function addon:COMBAT_LOG_EVENT_UNFILTERED(_, event, _, srcGUID, _, srcFlags, _, dstGUID, dstName, dstFlags, _, spellID, spellName, _, amount, overkill, ...)
	if event == "PARTY_KILL" and srcGUID == UnitGUID("player") then
		table.insert(partyKills, dstGUID)
	elseif event:find("_DAMAGE") and spellID ~= 116858 and srcGUID == UnitGUID("player") and overkill then
			for k,v in pairs(partyKills) do
				if v == dstGUID then
					table.remove(partyKills, k)
					break
				end
			end
	elseif event == "SPELL_DAMAGE" and spellID == 116858 and srcGUID == UnitGUID("player") then
		local msg

		if tContains(partyKills, dstGUID) and overkill then
			for k,v in pairs(partyKills) do
				if v == dstGUID then
					table.remove(partyKills, k)
					break
				end
			end
			
			if amount >= 100000 then
				if bit.band(dstFlags, COMBATLOG_OBJECT_TYPE_PLAYER) > 0 then
					msg = msgs.kill_named_amount[math.random(1, #msgs.kill_named_amount)]:format(dstName, addon:ShortNumber(amount), GetSpellLink(spellID))
					--SendChatMessage(dstName.." got owned by my "..addon:ShortNumber(amount).." "..GetSpellLink(spellID).." to the face!!!!", "YELL")
				else
					msg = msgs.kill_nonamed_amount[math.random(1, #msgs.kill_nonamed_amount)]:format(addon:ShortNumber(amount), GetSpellLink(spellID))
					--SendChatMessage(addon:ShortNumber(amount).." "..GetSpellLink(spellID).." owned to the face!!!!", "YELL")
				end
			else
				if bit.band(dstFlags, COMBATLOG_OBJECT_TYPE_PLAYER) > 0 then
					msg = msgs.kill_named_noamount[math.random(1, #msgs.kill_named_noamount)]:format(dstName, GetSpellLink(spellID))
					--SendChatMessage(dstName.." got owned by my "..GetSpellLink(spellID).." to the face!!!!", "YELL")
				else
					msg = msgs.kill_nonamed_noamount[math.random(1, #msgs.kill_nonamed_noamount)]:format(GetSpellLink(spellID))
					--SendChatMessage(GetSpellLink(spellID).." owned to the face!!!!", "YELL")
				end
			end
		else
			if amount >= 100000 then
				if bit.band(dstFlags, COMBATLOG_OBJECT_TYPE_PLAYER) > 0 then
					msg = msgs.nokill_named_amount[math.random(1, #msgs.nokill_named_amount)]:format(dstName, addon:ShortNumber(amount), GetSpellLink(spellID))
					--SendChatMessage(dstName.." took my "..addon:ShortNumber(amount).." "..GetSpellLink(spellID).." to the face!!!!", "YELL")
				else
					msg = msgs.nokill_nonamed_amount[math.random(1, #msgs.nokill_nonamed_amount)]:format(addon:ShortNumber(amount), GetSpellLink(spellID))
					--SendChatMessage(addon:ShortNumber(amount).." "..GetSpellLink(spellID).." to the face!!!!", "YELL")
				end
			else
				if bit.band(dstFlags, COMBATLOG_OBJECT_TYPE_PLAYER) > 0 then
					msg = msgs.nokill_named_noamount[math.random(1, #msgs.nokill_named_noamount)]:format(dstName, GetSpellLink(spellID))
					--SendChatMessage(dstName.." took my "..GetSpellLink(spellID).." to the face!!!!", "YELL")
				else
					msg = msgs.nokill_nonamed_noamount[math.random(1, #msgs.nokill_nonamed_noamount)]:format(GetSpellLink(spellID))
					--SendChatMessage(GetSpellLink(spellID).." to the face!!!!", "YELL")
				end
			end
		end

		SendChatMessage(msg, "YELL")
	end
end

function addon:ADDON_LOADED(name)
	if addonName == name then
		DEFAULT_CHAT_FRAME:AddMessage("|cffbb60ff"..addonName.."|r v|cff00ff00"..VERSION.."|r loaded.")
		addon:UnregisterEvent("ADDON_LOADED")
	end
end

function addon:PLAYER_ENTERING_WORLD()
	wipe(partyKills)
end

addon:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
addon:RegisterEvent("PLAYER_ENTERING_WORLD")
addon:RegisterEvent("ADDON_LOADED")

addon:SetScript("OnEvent", function(self, event, ...) addon[event](self, ...) end)